@@ -1,13 +1,12 @@
-// 	$Id: BoolNet.m,v 1.1.1.1 1998/01/08 00:37:55 alex Exp $	
+// 	$Id: BoolNet.m,v 1.3 1999/02/16 02:21:13 alex Exp $	
 
 #define __USE_FIXED_PROTOTYPES__  // for gcc headers
 
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <tkobjc.h>
 
-#import <boolnet.h>
+#import <booleannet.h>
 
 @implementation BoolNet
 
