@@ -9,7 +9,7 @@
   BOOL newState;                    // don't have graph buffered 
   int function;                     // Boolean function used to calculate new state
   
-  int boolId;                       // numerical ID of Boolean node 
+  unsigned boolId;                  // numerical ID of Boolean node 
   int periodicity;                  // classifies the periodicity of the node
 
   id boolNet ;                      // Boolean network it is a part of...
@@ -17,11 +17,11 @@
 
 // create-time messages
 
--setBoolFunc: (int) bf;             // set the boolean function type for the element
--setEntityId: (int) the_name;
--makeLinkFrom:  aNode ;             // create a link from "aNode"
--makeLinkFromWithInt: (int) aNumber ; // create a link from node with number "aNumber"
--placeX: (int) x Y: (int) y;
+- setBoolFunc: (int) bf;           //  boolean function type for the element
+- setEntityId: (unsigned)theId;
+- makeLinkFrom: aNode;             // create a link from "aNode"
+- makeLinkFromWithInt: (int)aNumber; // create  link from node with number
+- placeX: (unsigned)x Y: (unsigned)y;
 
 -createEnd;
 
@@ -30,7 +30,7 @@
 -setBoolNet: aBoolNet ;
 
 -(BOOL) getBoolState;               // get the current state of the element
--displayNodeState;                  // updates the display of the node on the "canvas"
+-displayNodeState;                  // updates the display of the node 
 -setBoolState: (BOOL) state;	    // force the element's Boolean state
 
 -(int) getPeriodicity;              // gets the periodicity of the node
@@ -42,8 +42,8 @@
 -getInputLinks;                     // returns the list of input links
 -(int) getNumInputs;                // gets the number of inputs 
 -(int) getNumOutputs;               // gets the number of outputs
--stepRule ;                         // each element handles calculation of new state
--update ;                           // updates the state of the Boolean network 
+-stepRule ;                         // handles calculation of new state
+-update ;                           // updates state of the node
                                     // called after stepRule
 -(int) updatePeriodicity;
 
